netapp_ontap.models.consistency_group_statistics API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.consistency_group_statistics`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class ConsistencyGroupStatisticsSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the ConsistencyGroupStatistics object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `available_space: Size GET`

    The total space available in the consistency group, in bytes.

    Example: 4096

  `iops_raw: PerformanceMetricIoType GET`

    The iops_raw field of the consistency_group_statistics.

  `latency_raw: PerformanceMetricIoType GET`

    The latency_raw field of the consistency_group_statistics.

  `size: Size GET`

    The total size of the consistency group, in bytes.

    Example: 4096

  `status: str GET`

    Errors associated with the sample. For example, if the aggregation of data over multiple nodes fails, then any partial errors might return "ok" on success or "error" on an internal uncategorized failure. Whenever a sample collection is missed but done at a later time, it is back filled to the previous 15 second timestamp and tagged with "backfilled_data". "Inconsistent_ delta_time" is encountered when the time between two collections is not the same for all nodes. Therefore, the aggregated value might be over or under inflated. "Negative_delta" is returned when an expected monotonically increasing value has decreased in value. "Inconsistent_old_data" is returned when one or more nodes do not have the latest data.

    Valid choices:

    - ok
    - error
    - partial_no_data
    - partial_no_uuid
    - partial_no_response
    - partial_other_error
    - negative_delta
    - backfilled_data
    - inconsistent_delta_time
    - inconsistent_old_data
  `throughput_raw: PerformanceMetricIoType GET`

    The throughput_raw field of the consistency_group_statistics.

  `timestamp: ImpreciseDateTime GET`

    The timestamp of the performance data.

    Example: 2017-01-25T11:20:13.000+0000

  `used_space: Size GET`

    The total used space in the consistency group, in bytes.

    Example: 4096